==> SELDOMpy-0.6.9.tar.gz: SELDOMpy-0.6.9/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree
import glob

from setuptools import find_packages, setup, Command, Extension
import numpy as np

# Package meta-data.
NAME = 'SELDOMpy'
DESCRIPTION = 'hardware acceleration'
URL = 'https://github.com/voxy/accel.git'
EMAIL = 'pradolopezluis@gmail.com'
AUTHOR = 'Luis Prado'

# What packages are required for this module to be executed?
REQUIRED = ["numpy", "scikit-learn", "pandas", "mealpy", "matplotlib", "setuptools"]

numpy_include = np.get_include()

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License,
# remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = '\n' + f.read()


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')

        sys.exit()


extra_compile_args = ["-DSDX_PLATFORM=xilinx:aws-vu9p-f1:4ddr-xpr-2pr:4.0",
                      "-D__USE_XOPEN2K8", "-I/opt/Xilinx/SDx/2017.1.op/runtime/include/1_2/",
                      "-I/opt/Xilinx/SDx/2017.1.op/Vivado_HLS/include/"]

extra_link_args = ["-shared", "-lxilinxopencl", "-lpthread", "-lrt",
                   "-L/opt/Xilinx/SDx/2017.1.op/runtime/lib/x86_64", "-lstdc++", ]

# Where the magic happens:
setup(
    name=NAME,
    version='0.6.9',
    description=DESCRIPTION,
    long_description=long_description,
    author=AUTHOR,
    author_email=EMAIL,
    url=URL,
    packages=find_packages(exclude=('tests',)),
    ext_modules=[Extension(
        "hello",
        sources=["SELDOMpy/src/AMIGO_problem.c", "SELDOMpy/src/cvodea.c", "SELDOMpy/src/cvodea_io.c",
                 "SELDOMpy/src/cvodes_band.c", "SELDOMpy/src/cvodes_bbdpre.c", "SELDOMpy/src/cvodes_diag.c",
                 "SELDOMpy/src/cvodes_dense.c", "SELDOMpy/src/cvodes_bandpre.c", "SELDOMpy/src/cvodes.c",
                 "SELDOMpy/src/AMIGO_model_stats.c", "SELDOMpy/src/AMIGO_model.c", "SELDOMpy/src/anODEModel.c",
                 "SELDOMpy/src/cvodes_direct.c", "SELDOMpy/src/cvodes_io.c", "SELDOMpy/src/cvodes_spbcgs.c",
                 "SELDOMpy/src/cvodes_spgmr.c", "SELDOMpy/src/cvodes_spils.c", "SELDOMpy/src/cvodes_sptfqmr.c",
                 "SELDOMpy/src/decimal2binary.c", "SELDOMpy/src/dhc.c", "SELDOMpy/src/fnvector_serial.c",
                 "SELDOMpy/src/findStates.c", "SELDOMpy/src/get_count_bits.c",
                 "SELDOMpy/src/get_support_truth_tables.c",
                 "SELDOMpy/src/get_input_index.c", "SELDOMpy/src/get_truth_tables_index.c",
                 "SELDOMpy/src/getAdjacencyMatrix.c",
                 "SELDOMpy/src/getNumBits.c", "SELDOMpy/src/getNumInputs.c", "SELDOMpy/src/getStateIndex.c",
                 "SELDOMpy/src/getTruthTables.c",
                 "SELDOMpy/src/hill_function.c", "SELDOMpy/src/linear_transfer_function.c", "SELDOMpy/src/normHill.c",
                 "SELDOMpy/src/nvector_serial.c", "SELDOMpy/src/printAdjMat.c", "SELDOMpy/src/printInterMat.c",
                 "SELDOMpy/src/printNminiTerms.c", "SELDOMpy/src/printTruthTables.c", "SELDOMpy/src/sim_logic_ode.c",
                 "SELDOMpy/src/simulate_amigo_model.c",
                 "SELDOMpy/src/sundials_band.c",
                 "SELDOMpy/src/sundials_dense.c", "SELDOMpy/src/sundials_direct.c", "SELDOMpy/src/sundials_iterative.c",
                 "SELDOMpy/src/sundials_math.c", "SELDOMpy/src/sundials_nvector.c", "SELDOMpy/src/sundials_spbcgs.c",
                 "SELDOMpy/src/sundials_spgmr.c", "SELDOMpy/src/sundials_sptfqmr.c"],
        include_dirs=['SELDOMpy/include/include_amigo', 'SELDOMpy/include/include_cvodes', "SELDOMpy/src", numpy_include],
        extra_compile_args=extra_compile_args,
        extra_link_args=extra_link_args,
    )],

    # If your package is a single module, use this instead of 'packages':
    # py_modules=['slideshows'],

    install_requires=REQUIRED,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
    # $ setup.py publish support.
    cmdclass={
        'upload': UploadCommand,
    },
)

==> SELDOMpy-0.8.2.1.tar.gz: SELDOMpy-0.8.2.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree
import glob

from setuptools import find_packages, setup, Command, Extension
import numpy as np

# Package meta-data.
NAME = 'SELDOMpy'
DESCRIPTION = 'hardware acceleration'
URL = 'https://github.com/voxy/accel.git'
EMAIL = 'pradolopezluis@gmail.com'
AUTHOR = 'Luis Prado'

# What packages are required for this module to be executed?
REQUIRED = ["numpy", "scikit-learn", "pandas", "mealpy", "matplotlib", "setuptools", "openpyxl"]

numpy_include = np.get_include()

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License,
# remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = '\n' + f.read()


extra_compile_args = ["-DSDX_PLATFORM=xilinx:aws-vu9p-f1:4ddr-xpr-2pr:4.0",
                      "-D__USE_XOPEN2K8", "-I/opt/Xilinx/SDx/2017.1.op/runtime/include/1_2/",
                      "-I/opt/Xilinx/SDx/2017.1.op/Vivado_HLS/include/"]

extra_link_args = ["-shared", "-lxilinxopencl", "-lpthread", "-lrt",
                   "-L/opt/Xilinx/SDx/2017.1.op/runtime/lib/x86_64", "-lstdc++", ]

# Where the magic happens:
setup(
    name=NAME,
    version='0.8.2.1',
    description=DESCRIPTION,
    long_description=long_description,
    author=AUTHOR,
    author_email=EMAIL,
    url=URL,
    packages=find_packages(exclude=('tests',)),
    ext_modules=[Extension(
        "hello",
        sources=["SELDOMpy/src/AMIGO_problem.c", "SELDOMpy/src/cvodea.c", "SELDOMpy/src/cvodea_io.c",
                 "SELDOMpy/src/cvodes_band.c", "SELDOMpy/src/cvodes_bbdpre.c", "SELDOMpy/src/cvodes_diag.c",
                 "SELDOMpy/src/cvodes_dense.c", "SELDOMpy/src/cvodes_bandpre.c", "SELDOMpy/src/cvodes.c",
                 "SELDOMpy/src/AMIGO_model_stats.c", "SELDOMpy/src/AMIGO_model.c", "SELDOMpy/src/anODEModel.c",
                 "SELDOMpy/src/cvodes_direct.c", "SELDOMpy/src/cvodes_io.c", "SELDOMpy/src/cvodes_spbcgs.c",
                 "SELDOMpy/src/cvodes_spgmr.c", "SELDOMpy/src/cvodes_spils.c", "SELDOMpy/src/cvodes_sptfqmr.c",
                 "SELDOMpy/src/decimal2binary.c", "SELDOMpy/src/dhc.c", "SELDOMpy/src/fnvector_serial.c",
                 "SELDOMpy/src/findStates.c", "SELDOMpy/src/get_count_bits.c",
                 "SELDOMpy/src/get_support_truth_tables.c",
                 "SELDOMpy/src/get_input_index.c", "SELDOMpy/src/get_truth_tables_index.c",
                 "SELDOMpy/src/getAdjacencyMatrix.c",
                 "SELDOMpy/src/getNumBits.c", "SELDOMpy/src/getNumInputs.c", "SELDOMpy/src/getStateIndex.c",
                 "SELDOMpy/src/getTruthTables.c",
                 "SELDOMpy/src/hill_function.c", "SELDOMpy/src/linear_transfer_function.c", "SELDOMpy/src/normHill.c",
                 "SELDOMpy/src/nvector_serial.c", "SELDOMpy/src/printAdjMat.c", "SELDOMpy/src/printInterMat.c",
                 "SELDOMpy/src/printNminiTerms.c", "SELDOMpy/src/printTruthTables.c", "SELDOMpy/src/sim_logic_ode.c",
                 "SELDOMpy/src/simulate_amigo_model.c",
                 "SELDOMpy/src/sundials_band.c",
                 "SELDOMpy/src/sundials_dense.c", "SELDOMpy/src/sundials_direct.c", "SELDOMpy/src/sundials_iterative.c",
                 "SELDOMpy/src/sundials_math.c", "SELDOMpy/src/sundials_nvector.c", "SELDOMpy/src/sundials_spbcgs.c",
                 "SELDOMpy/src/sundials_spgmr.c", "SELDOMpy/src/sundials_sptfqmr.c", "SELDOMpy/include/include_amigo/AMIGO_model.h"],
        include_dirs=['SELDOMpy/include/include_amigo', 'SELDOMpy/include/include_cvodes', "SELDOMpy/src", numpy_include],
        extra_compile_args=extra_compile_args,
        extra_link_args=extra_link_args,
    )],

    # If your package is a single module, use this instead of 'packages':
    # py_modules=['slideshows'],

    install_requires=REQUIRED,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
)
